'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

var _lodash = require('lodash');

var _lodash2 = _interopRequireDefault(_lodash);

var XmlConverter = (function () {
    function XmlConverter() {
        _classCallCheck(this, XmlConverter);
    }

    _createClass(XmlConverter, [{
        key: 'convert',

        /**
         * Converts an object to an xml string
         *
         * @param {object} object The source object
         *
         * @return {string} XML string result
         */
        value: function convert(object) {
            var xmlStringParts = ['<?xml version="1.0" encoding="UTF-8"?>', this.convertObject(object)];

            return xmlStringParts.join('');
        }

        /**
         * Processes an object
         *
         * @private
         *
         * @param {object} object The source object
         *
         * @return {string} XML string result
         */
    }, {
        key: 'convertObject',
        value: function convertObject(object) {
            var _this = this;

            var xml = [];

            _lodash2['default'].forOwn(object, function (value, key) {
                if (_lodash2['default'].isNumber(value) || !_lodash2['default'].isEmpty(value)) {
                    xml.push(_this.processObjectProperty(key, value));
                }
            });

            return xml.join('');
        }

        /**
         * Processes an object property with its key
         *
         * @private
         *
         * @param {string} key Object key
         * @param {string|array|object} value Object value
         *
         * @return {string} XML string result
         */
    }, {
        key: 'processObjectProperty',
        value: function processObjectProperty(key, value) {
            if (_lodash2['default'].isPlainObject(value)) {
                var convertedObject = this.convertObject(value);
                return !_lodash2['default'].isEmpty(convertedObject) ? this.createNode(key, convertedObject) : '';
            }

            if (_lodash2['default'].isArray(value)) {
                return this.convertArray(key, value);
            }

            return this.createNode(key, this.escapeValue(value));
        }

        /**
         * Processes an array
         *
         * @private
         *
         * @param {string} key The xml node key
         * @param {array} arr The source array
         *
         * @return {string} XML string result
         */
    }, {
        key: 'convertArray',
        value: function convertArray(key, arr) {
            var _this2 = this;

            var xml = [];

            _lodash2['default'].each(arr, function (item) {
                if (_lodash2['default'].isPlainObject(item)) {
                    return xml.push(_this2.createNode(key, _this2.convertObject(item)));
                }

                return xml.push(_this2.createNode(key, _this2.escapeValue(item)));
            });

            return xml.join('');
        }

        /**
         * Creates a single xml node
         *
         * @private
         *
         * @param {string} key Node identifier
         * @param {string} value Node content
         *
         * @return {string} XML string result
         */
    }, {
        key: 'createNode',
        value: function createNode(key, value) {
            return '<' + key + '>' + value + '</' + key + '>';
        }

        /**
         * Escapes a string value for propper xml formatting
         *
         * @private
         *
         * @param {string} str The target string value
         *
         * @return {string} Escaped string
         */
    }, {
        key: 'escapeValue',
        value: function escapeValue(str) {
            return !_lodash2['default'].isString(str) ? str : str.replace(/[<>&'"]/g, function (char) {
                switch (char) {
                    /* eslint-disable */
                    case '<':
                        return '&lt;';
                    case '>':
                        return '&gt;';
                    case '&':
                        return '&amp;';
                    case '\'':
                        return '&apos;';
                    case '"':
                        return '&apos;';
                    /* eslint-enable */
                }
            });
        }
    }], [{
        key: 'toXml',

        /**
         * Converts an object to an xml string | static call
         *
         * @param {object} object The source object
         *
         * @return {string} XML string result
         */
        value: function toXml(object) {
            return new XmlConverter().convert(object);
        }
    }]);

    return XmlConverter;
})();

exports['default'] = XmlConverter;
module.exports = exports['default'];

